.. raw:: rst
   :file: badges.rst

.. raw:: rst
   :file: long_description.rst

.. raw:: rst

   Build status: |build-status|
   
   Latest Pypi release: |pypi|
   
   Read the documentation: |docs|
   
..

.. raw:: rst
   :file: install.rst

.. raw:: rst

   Changelog
   ---------------
   `docs/source/changelog.rst <docs/source/changelog.rst>`_

.. raw:: rst
   :file: tests.rst


.. raw:: rst

   Authors:
     * Pierre Quentel (pierre.quentel@gmail.com)
     * Bendik Rønning Opstad (bro.development@gmail.com)
